import { Logger } from '@nldoc/logger';
import { WorkerConfig } from './types/WorkerConfig.js';
import { WorkerMessageHandler } from './types/WorkerMessageHandler.js';
export declare class Worker {
    private amqpChannel?;
    private amqpClient?;
    private readonly amqpHost;
    private readonly amqpPass?;
    private readonly amqpPort;
    private readonly amqpProtocol;
    private readonly amqpUser?;
    private availabilityInterval?;
    private readonly exchangeHealth;
    private readonly exchangeJobs;
    private readonly exchangePrefix?;
    private readonly exchangeResults;
    private readonly jobAckRoutingKeyPrefix;
    private readonly jobPattern;
    private readonly jobResultRoutingKeyPrefix;
    private readonly stationWorkerScoutRoutingKey;
    private readonly minioHost?;
    private readonly minioPort?;
    private readonly minioAccessKey?;
    private readonly minioSecretKey?;
    private readonly minioOutputBucketName?;
    private readonly minioDebugBucketName?;
    private readonly minioUseSSL;
    private minioClient?;
    private readonly logger;
    private readonly messageHandler;
    private readonly prefetchLimit;
    private readonly queue;
    private readonly inFlight;
    private shuttingDown;
    private readonly workerInstanceName;
    private readonly workerName;
    private readonly workerType;
    private readonly instanceTraceId;
    private readonly heartbeatIntervalSeconds;
    constructor({ logger, messageHandler, config, traceId, }: {
        logger: Logger;
        messageHandler: WorkerMessageHandler;
        config: WorkerConfig;
        traceId?: string;
    });
    getInfo(): {
        amqpHost: string;
        amqpPort: number;
        amqpProtocol: string;
        prefetchLimit: number;
        exchangeJobs: string;
        exchangeHealth: string;
        exchangeResults: string;
        queue: string;
        workerInstance: string;
        workerName: string;
        workerType: string;
    };
    start(): Promise<void>;
    restart(): Promise<void>;
    private attachExternalEventListeners;
    private onTerminationSignal;
    private inFlightDrained;
    shutdown: () => Promise<never>;
    private connectMinio;
    private connect;
    private setupAmqpChannel;
    private assertChannel;
    private handleConnectionError;
    private handleConnectionClose;
    private assertExchanges;
    private assertExchange;
    private assertQueue;
    private bindQueues;
    private bindQueue;
    private publish;
    private sendAvailability;
    private startHeartbeat;
    private heartbeat;
    private sendJobAck;
    private checkJobMessageRoutingKey;
    private parseJobMessage;
    private publishResult;
    private consumeChannel;
    private handleMessage;
    private handleMessageAsync;
    private handleWorkerScoutMessage;
    private processJob;
    private handleProcessingError;
    private tryParseJson;
    private storeJobInMinio;
}
