import z from 'zod';
const BaseWorkerResult = z.object({
    traceId: z.string(),
    recordId: z.string(),
    jobId: z.string(),
    timestamp: z.string().nullable(),
    success: z.boolean(),
    confidence: z.number(),
    error: z
        .object({
        code: z.number(),
        message: z.string(),
    })
        .optional()
        .nullable(),
});
export const AttributeWorkerResult = BaseWorkerResult.extend({
    stringResult: z.string().nullable(),
});
export const AttributeWorkerHandlerResult = AttributeWorkerResult.omit({
    traceId: true,
    recordId: true,
    jobId: true,
    timestamp: true,
});
export const PageWorkerPDFInfo = z.object({
    author: z.string().optional().nullable(),
    creator: z.string().optional().nullable(),
    producer: z.string().optional().nullable(),
    title: z.string().optional().nullable(),
    subject: z.string().optional().nullable(),
    creationDate: z.string().optional().nullable(),
    modificationDate: z.string().optional().nullable(),
    pdfVersion: z.string().optional().nullable(),
    pageSize: z.string().optional().nullable(),
    form: z.string().optional().nullable(),
    hasJavascript: z.boolean().optional().nullable(),
    isEncrypted: z.boolean().optional().nullable(),
});
export const PageWorkerResult = BaseWorkerResult.extend({
    pageResult: z
        .object({
        pageCount: z.number(),
        bucketName: z.string(),
        bucketPath: z.string(),
        fileExtension: z.string(),
        pdfInfo: PageWorkerPDFInfo,
    })
        .nullable(),
});
export const PageWorkerHandlerResult = PageWorkerResult.omit({
    traceId: true,
    recordId: true,
    jobId: true,
    timestamp: true,
});
export const ElementWorkerResult = BaseWorkerResult.extend({
    elementResult: z
        .object({
        elementCount: z.number(),
        bucketName: z.string(),
        bucketPath: z.string(),
        fileExtension: z.string(),
    })
        .nullable(),
});
export const ElementWorkerHandlerResult = ElementWorkerResult.omit({
    traceId: true,
    recordId: true,
    jobId: true,
    timestamp: true,
});
export const FileWorkerResult = BaseWorkerResult.extend({
    fileResult: z
        .object({
        bucketName: z.string(),
        bucketPath: z.string(),
        fileExtension: z.string(),
        fileType: z.string(),
    })
        .nullable(),
});
export const FileWorkerHandlerResult = FileWorkerResult.omit({
    traceId: true,
    recordId: true,
    jobId: true,
    timestamp: true,
});
export const WorkerResult = z.union([
    AttributeWorkerResult,
    PageWorkerResult,
    ElementWorkerResult,
    FileWorkerResult,
]);
export const WorkerMessageHandlerResult = z.union([
    AttributeWorkerHandlerResult,
    PageWorkerHandlerResult,
    ElementWorkerHandlerResult,
    FileWorkerHandlerResult,
]);
//# sourceMappingURL=WorkerResult.js.map